@@ -44,7 +44,7 @@ typedef struct {
 
 extern struct JSClass gjs_error_class;
 
-static void define_error_properties(JSContext *, JSObject *);
+static void define_error_properties(JSContext *, JS::HandleObject);
 
 GJS_DEFINE_PRIV_FROM_JS(Error, gjs_error_class)
 
@@ -96,17 +96,14 @@ GJS_NATIVE_CONSTRUCTOR_DECLARE(error)
     priv->domain = proto_priv->domain;
 
     JS::RootedObject params_obj(context, &argv[0].toObject());
-    JS::RootedId message_name(context,
-        gjs_context_get_const_string(context, GJS_STRING_MESSAGE));
-    JS::RootedId code_name(context,
-        gjs_context_get_const_string(context, GJS_STRING_CODE));
-    if (!gjs_object_require_property_value(context, params_obj,
-                                           "GError constructor", message_name,
-                                           &message))
+    if (!gjs_object_require_property(context, params_obj,
+                                     "GError constructor",
+                                     GJS_STRING_MESSAGE, &message))
         return false;
-    if (!gjs_object_require_property_value(context, params_obj,
-                                           "GError constructor", code_name,
-                                           &code))
+
+    if (!gjs_object_require_property(context, params_obj,
+                                     "GError constructor",
+                                     GJS_STRING_CODE, &code))
         return false;
 
     priv->gerror = g_error_new_literal(priv->domain, code, message);
@@ -246,12 +243,10 @@ error_constructor_value_of(JSContext *context,
 {
     GJS_GET_THIS(context, argc, vp, rec, self);
     Error *priv;
-    JS::RootedId prototype_name(context,
-        gjs_context_get_const_string(context, GJS_STRING_PROTOTYPE));
     JS::RootedObject prototype(context);
 
-    if (!gjs_object_require_property_value(context, self, "constructor",
-                                           prototype_name, &prototype)) {
+    if (!gjs_object_require_property(context, self, "constructor",
+                                     GJS_STRING_PROTOTYPE, &prototype)) {
         /* This error message will be more informative */
         JS_ClearPendingException(context);
         gjs_throw(context, "GLib.Error.valueOf() called on something that is not"
@@ -276,16 +271,15 @@ error_constructor_value_of(JSContext *context,
 struct JSClass gjs_error_class = {
     "GLib_Error",
     JSCLASS_HAS_PRIVATE |
-    JSCLASS_NEW_RESOLVE |
     JSCLASS_BACKGROUND_FINALIZE |
     JSCLASS_IMPLEMENTS_BARRIERS,
-    JS_PropertyStub,
-    JS_DeletePropertyStub,
-    JS_PropertyStub,
-    JS_StrictPropertyStub,
-    JS_EnumerateStub,
-    JS_ResolveStub,
-    JS_ConvertStub,
+    NULL,  /* addProperty */
+    NULL,  /* deleteProperty */
+    NULL,  /* getProperty */
+    NULL,  /* setProperty */
+    NULL,  /* enumerate */
+    NULL,  /* resolve */
+    NULL,  /* convert */
     error_finalize
 };
 
@@ -397,34 +391,26 @@ find_error_domain_info(GQuark domain)
    fileName, lineNumber and stack
 */
 static void
-define_error_properties(JSContext *context,
-                        JSObject  *obj)
+define_error_properties(JSContext       *context,
+                        JS::HandleObject obj)
 {
     JS::RootedValue stack(context), fileName(context), lineNumber(context);
     /* COMPAT: mozilla::Maybe gains a much more usable API in future versions */
-    mozilla::Maybe<JS::MutableHandleValue> m_stack, m_file, m_line;
-    m_stack.construct(&stack);
-    m_file.construct(&fileName);
-    m_line.construct(&lineNumber);
+    auto m_stack = mozilla::Some<JS::MutableHandleValue>(&stack);
+    auto m_file = mozilla::Some<JS::MutableHandleValue>(&fileName);
+    auto m_line = mozilla::Some<JS::MutableHandleValue>(&lineNumber);
 
     if (!gjs_context_get_frame_info(context, m_stack, m_file, m_line))
         return;
 
-    JS::RootedId stack_name(context,
-        gjs_context_get_const_string(context, GJS_STRING_STACK));
-    JS::RootedId filename_name(context,
-        gjs_context_get_const_string(context, GJS_STRING_FILENAME));
-    JS::RootedId linenumber_name(context,
-        gjs_context_get_const_string(context, GJS_STRING_LINE_NUMBER));
+    gjs_object_define_property(context, obj, GJS_STRING_STACK, stack,
+                               JSPROP_ENUMERATE);
 
-    JS_DefinePropertyById(context, obj, stack_name, stack,
-                          NULL, NULL, JSPROP_ENUMERATE);
+    gjs_object_define_property(context, obj, GJS_STRING_FILENAME,
+                               fileName, JSPROP_ENUMERATE);
 
-    JS_DefinePropertyById(context, obj, filename_name, fileName,
-                          NULL, NULL, JSPROP_ENUMERATE);
-
-    JS_DefinePropertyById(context, obj, linenumber_name, lineNumber,
-                          NULL, NULL, JSPROP_ENUMERATE);
+    gjs_object_define_property(context, obj, GJS_STRING_LINE_NUMBER,
+                               lineNumber, JSPROP_ENUMERATE);
 }
 
 JSObject*
@@ -432,7 +418,6 @@ gjs_error_from_gerror(JSContext             *context,
                       GError                *gerror,
                       bool                   add_stack)
 {
-    JSObject *obj;
     Error *priv;
     Error *proto_priv;
     GIEnumInfo *info;
@@ -463,7 +448,8 @@ gjs_error_from_gerror(JSContext             *context,
     JS::RootedObject global(context, gjs_get_import_global(context));
     proto_priv = priv_from_js(context, proto);
 
-    obj = JS_NewObjectWithGivenProto(context, JS_GetClass(proto), proto, global);
+    JS::RootedObject obj(context,
+        JS_NewObjectWithGivenProto(context, JS_GetClass(proto), proto, global));
 
     GJS_INC_COUNTER(gerror);
     priv = g_slice_new0(Error);
