@@ -57,7 +57,7 @@ param_resolve(JSContext       *context,
     GIObjectInfo *info = NULL;
     GIFunctionInfo *method_info;
     Param *priv;
-    g_autofree char *name = NULL;
+    char *name = NULL;
     bool ret = false;
 
     if (!gjs_get_string_id(context, id, &name))
@@ -68,6 +68,7 @@ param_resolve(JSContext       *context,
     if (priv != NULL) {
         /* instance, not prototype */
         *resolved = false;
+        g_free(name);
         return true;
     }
 
@@ -100,6 +101,7 @@ param_resolve(JSContext       *context,
 
     ret = true;
  out:
+    g_free(name); 
     if (info != NULL)
         g_base_info_unref( (GIBaseInfo*)info);
 
