@@ -155,7 +155,7 @@ repo_resolve(JSContext       *context,
              bool            *resolved)
 {
     Repo *priv;
-    g_autofree char *name = NULL;
+    char *name = NULL;
 
     if (!gjs_get_string_id(context, id, &name)) {
         *resolved = false;
@@ -166,6 +166,7 @@ repo_resolve(JSContext       *context,
     if (strcmp(name, "valueOf") == 0 ||
         strcmp(name, "toString") == 0) {
         *resolved = false;
+        g_free(name);
         return true;
     }
 
@@ -176,13 +177,17 @@ repo_resolve(JSContext       *context,
     if (priv == NULL) {
         /* we are the prototype, or have the wrong class */
         *resolved = false;
+        g_free(name);
         return true;
     }
 
-    if (!resolve_namespace_object(context, obj, id, name))
+    if (!resolve_namespace_object(context, obj, id, name)) {
+        g_free(name);
         return false;
+    }
 
     *resolved = true;
+    g_free(name);
     return true;
 }
 
