@@ -33,8 +33,10 @@ G_BEGIN_DECLS
 bool      gjs_create_root_importer (JSContext   *context,
                                     const char **initial_search_path,
                                     bool         add_standard_search_path);
-bool      gjs_define_root_importer (JSContext   *context,
-                                    JSObject    *in_object);
+
+bool gjs_define_root_importer(JSContext       *cx,
+                              JS::HandleObject in_object);
+
 bool      gjs_define_root_importer_object(JSContext        *context,
                                           JS::HandleObject  in_object,
                                           JS::HandleObject  root_importer);
