@@ -24,15 +24,42 @@
 #ifndef __GJS_JSAPI_UTIL_H__
 #define __GJS_JSAPI_UTIL_H__
 
+#include <memory>
 #include <stdbool.h>
 
 #include <glib-object.h>
-#include <mozilla/Maybe.h>
 
 #include "jsapi-wrapper.h"
 #include "gjs/runtime.h"
 #include "gi/gtype.h"
 
+class GjsAutoChar : public std::unique_ptr<char, decltype(&g_free)> {
+public:
+    typedef std::unique_ptr<char, decltype(&g_free)> U;
+
+    GjsAutoChar(char *str = nullptr) : U(str, g_free) {}
+
+    operator const char *() {
+        return get();
+    }
+
+    void operator= (const char* str) {
+        reset(const_cast<char*>(str));
+    }
+};
+
+template <typename T>
+class GjsAutoUnref : public std::unique_ptr<T, decltype(&g_object_unref)> {
+public:
+    typedef std::unique_ptr<T, decltype(&g_object_unref)> U;
+
+    GjsAutoUnref(T *ptr = nullptr) : U(ptr, g_object_unref) {}
+
+    operator T *() {
+        return U::get();
+    }
+};
+
 G_BEGIN_DECLS
 
 #define GJS_UTIL_ERROR gjs_util_error_quark ()
@@ -77,7 +104,7 @@ typedef struct GjsRootedArray GjsRootedArray;
  *                              do_base_typecheck and priv_from_js
  */
 #define GJS_DEFINE_PRIV_FROM_JS(type, klass)                          \
-    __attribute__((unused)) static inline bool                          \
+    G_GNUC_UNUSED static inline bool                                    \
     do_base_typecheck(JSContext       *context,                         \
                       JS::HandleObject object,                          \
                       bool             throw_error)                     \
@@ -94,7 +121,7 @@ typedef struct GjsRootedArray GjsRootedArray;
         JS_EndRequest(context);                                         \
         return priv;                                                    \
     }                                                                   \
-    __attribute__((unused)) static bool                                 \
+    G_GNUC_UNUSED static bool                                           \
     priv_from_js_with_typecheck(JSContext       *context,               \
                                 JS::HandleObject object,                \
                                 type           **out)                   \
@@ -176,24 +203,16 @@ _GJS_DEFINE_PROTO_FULL(tn, cn, NULL, gtype, flags)
 extern JSPropertySpec gjs_##cname##_proto_props[]; \
 extern JSFunctionSpec gjs_##cname##_proto_funcs[]; \
 static void gjs_##cname##_finalize(JSFreeOp *fop, JSObject *obj); \
-static bool gjs_##cname##_new_resolve(JSContext *context, \
-                                      JSObject  *obj, \
-                                      JS::Value  id, \
-                                      JSObject **objp) \
-{ \
-    return true; \
-} \
 static struct JSClass gjs_##cname##_class = { \
     type_name, \
-    JSCLASS_HAS_PRIVATE | \
-    JSCLASS_NEW_RESOLVE | jsclass_flags, \
-    JS_PropertyStub, \
-    JS_DeletePropertyStub, \
-    JS_PropertyStub, \
-    JS_StrictPropertyStub, \
-    JS_EnumerateStub,\
-    (JSResolveOp) gjs_##cname##_new_resolve, \
-    JS_ConvertStub, \
+    JSCLASS_HAS_PRIVATE | jsclass_flags,                                       \
+    NULL,  /* addProperty */                                                   \
+    NULL,  /* deleteProperty */                                                \
+    NULL,  /* getProperty */                                                   \
+    NULL,  /* setProperty */                                                   \
+    NULL,  /* enumerate */                                                     \
+    NULL,  /* resolve */                                                       \
+    NULL,  /* convert */                                                       \
     gjs_##cname##_finalize                                                     \
 }; \
 JS::Value                                                                      \
@@ -206,32 +225,36 @@ gjs_##cname##_create_proto(JSContext *context,                                 \
     JS::RootedObject global(context, gjs_get_import_global(context));          \
     JS::RootedId class_name(context,                                           \
         gjs_intern_string_to_id(context, gjs_##cname##_class.name));           \
-    if (!JS_GetPropertyById(context, global, class_name, &rval))               \
+    bool found = false;                                                        \
+    if (!JS_AlreadyHasOwnPropertyById(context, global, class_name, &found))    \
         return JS::NullValue(); \
-    if (rval.isUndefined()) { \
-        JS::RootedObject prototype(context,                                    \
-            JS_InitClass(context, global, parent, &gjs_##cname##_class, ctor,  \
-                         0, &gjs_##cname##_proto_props[0],                     \
-                         &gjs_##cname##_proto_funcs[0],                        \
-                         NULL, NULL));                                         \
-        if (prototype == NULL) { \
-            return JS::NullValue(); \
-        } \
-        if (!gjs_object_require_property( \
-                context, global, NULL, \
-                class_name, &rval)) { \
-            return JS::NullValue(); \
-        } \
-        if (!JS_DefineProperty(context, module, proto_name, \
-                               rval, GJS_MODULE_PROP_FLAGS))                   \
-            return JS::NullValue(); \
-        if (gtype != G_TYPE_NONE) { \
-            JS::RootedObject rval_obj(context, &rval.toObject());              \
-            JS::RootedObject gtype_obj(context,                                \
-                gjs_gtype_create_gtype_wrapper(context, gtype));               \
-            JS_DefineProperty(context, rval_obj, "$gtype", gtype_obj,          \
-                              JSPROP_PERMANENT);                               \
-        } \
+    if (found) {                                                               \
+        if (!JS_GetPropertyById(context, global, class_name, &rval))           \
+            return JS::NullValue();                                            \
+        return rval;                                                           \
+    }                                                                          \
+    JS::RootedObject prototype(context,                                        \
+        JS_InitClass(context, global, parent, &gjs_##cname##_class, ctor,      \
+                     0, &gjs_##cname##_proto_props[0],                         \
+                     &gjs_##cname##_proto_funcs[0],                            \
+                     NULL, NULL));                                             \
+    if (prototype == NULL) { \
+        return JS::NullValue(); \
+    } \
+    if (!gjs_object_require_property( \
+            context, global, NULL, \
+            class_name, &rval)) { \
+        return JS::NullValue(); \
+    } \
+    if (!JS_DefineProperty(context, module, proto_name, \
+                           rval, GJS_MODULE_PROP_FLAGS))                       \
+        return JS::NullValue(); \
+    if (gtype != G_TYPE_NONE) { \
+        JS::RootedObject rval_obj(context, &rval.toObject());                  \
+        JS::RootedObject gtype_obj(context,                                    \
+            gjs_gtype_create_gtype_wrapper(context, gtype));                   \
+        JS_DefineProperty(context, rval_obj, "$gtype", gtype_obj,              \
+                          JSPROP_PERMANENT);                                   \
     } \
     return rval; \
 }
@@ -303,19 +326,6 @@ void        gjs_set_global_slot              (JSContext       *context,
                                               GjsGlobalSlot    slot,
                                               JS::Value        value);
 
-bool gjs_object_require_property(JSContext             *context,
-                                 JS::HandleObject       obj,
-                                 const char            *obj_description,
-                                 JS::HandleId           property_name,
-                                 JS::MutableHandleValue value);
-
-/* This is intended to be overloaded with more types as the opportunity arises */
-bool gjs_object_require_converted_property_value(JSContext       *context,
-                                                 JS::HandleObject obj,
-                                                 const char      *description,
-                                                 JS::HandleId     property_name,
-                                                 uint32_t        *value);
-
 bool gjs_init_class_dynamic(JSContext              *context,
                             JS::HandleObject        in_object,
                             JS::HandleObject        parent_proto,
@@ -338,7 +348,7 @@ void gjs_throw_abstract_constructor_error(JSContext    *context,
 
 bool gjs_typecheck_instance(JSContext       *context,
                             JS::HandleObject obj,
-                            JSClass         *static_clasp,
+                            const JSClass   *static_clasp,
                             bool             throw_error);
 
 JSObject *gjs_construct_object_dynamic(JSContext                  *context,
@@ -477,45 +487,112 @@ typedef enum {
   GJS_STRING_LAST
 } GjsConstString;
 
-jsid              gjs_context_get_const_string  (JSContext       *context,
-                                                 GjsConstString   string);
-
-bool gjs_object_get_property_const(JSContext             *cx,
-                                   JS::HandleObject       obj,
-                                   GjsConstString         property_name,
-                                   JS::MutableHandleValue value_p);
-
 const char * gjs_strip_unix_shebang(const char *script,
                                     gssize     *script_len,
                                     int        *new_start_line_number);
 
+/* These four functions wrap JS_GetPropertyById(), etc., but with a
+ * GjsConstString constant instead of a jsid. */
+
+bool gjs_object_get_property(JSContext             *cx,
+                             JS::HandleObject       obj,
+                             GjsConstString         property_name,
+                             JS::MutableHandleValue value_p);
+
+bool gjs_object_set_property(JSContext       *cx,
+                             JS::HandleObject obj,
+                             GjsConstString   property_name,
+                             JS::HandleValue  value);
+
+bool gjs_object_has_property(JSContext       *cx,
+                             JS::HandleObject obj,
+                             GjsConstString   property_name,
+                             bool            *found);
+
 G_END_DECLS
 
+bool gjs_object_define_property(JSContext       *cx,
+                                JS::HandleObject obj,
+                                GjsConstString   property_name,
+                                JS::HandleValue  value,
+                                unsigned         flags,
+                                JSNative         getter = nullptr,
+                                JSNative         setter = nullptr);
+
+bool gjs_object_define_property(JSContext       *cx,
+                                JS::HandleObject obj,
+                                GjsConstString   property_name,
+                                JS::HandleObject value,
+                                unsigned         flags,
+                                JSNative         getter = nullptr,
+                                JSNative         setter = nullptr);
+
+JS::HandleId gjs_context_get_const_string(JSContext     *cx,
+                                          GjsConstString string);
+
 /* Overloaded functions, must be outside G_DECLS. More types are intended to be
  * added as the opportunity arises. */
 
-bool gjs_object_require_property_value(JSContext       *cx,
-                                       JS::HandleObject obj,
-                                       const char      *description,
-                                       JS::HandleId     property_name,
-                                       bool            *value);
+bool gjs_object_require_property(JSContext             *context,
+                                 JS::HandleObject       obj,
+                                 const char            *obj_description,
+                                 JS::HandleId           property_name,
+                                 JS::MutableHandleValue value);
 
-bool gjs_object_require_property_value(JSContext       *cx,
-                                       JS::HandleObject obj,
-                                       const char      *description,
-                                       JS::HandleId     property_name,
-                                       int32_t         *value);
+bool gjs_object_require_property(JSContext       *cx,
+                                 JS::HandleObject obj,
+                                 const char      *description,
+                                 JS::HandleId     property_name,
+                                 bool            *value);
 
-bool gjs_object_require_property_value(JSContext       *cx,
-                                       JS::HandleObject obj,
-                                       const char      *description,
-                                       JS::HandleId     property_name,
-                                       char           **value);
+bool gjs_object_require_property(JSContext       *cx,
+                                 JS::HandleObject obj,
+                                 const char      *description,
+                                 JS::HandleId     property_name,
+                                 int32_t         *value);
 
-bool gjs_object_require_property_value(JSContext              *cx,
-                                       JS::HandleObject        obj,
-                                       const char             *description,
-                                       JS::HandleId            property_name,
-                                       JS::MutableHandleObject value);
+bool gjs_object_require_property(JSContext       *cx,
+                                 JS::HandleObject obj,
+                                 const char      *description,
+                                 JS::HandleId     property_name,
+                                 char           **value);
+
+bool gjs_object_require_property(JSContext              *cx,
+                                 JS::HandleObject        obj,
+                                 const char             *description,
+                                 JS::HandleId            property_name,
+                                 JS::MutableHandleObject value);
+
+bool gjs_object_require_converted_property(JSContext       *context,
+                                           JS::HandleObject obj,
+                                           const char      *description,
+                                           JS::HandleId     property_name,
+                                           uint32_t        *value);
+
+/* Here, too, we have wrappers that take a GjsConstString. */
+
+template<typename T>
+bool gjs_object_require_property(JSContext        *cx,
+                                 JS::HandleObject  obj,
+                                 const char       *description,
+                                 GjsConstString    property_name,
+                                 T                 value)
+{
+    return gjs_object_require_property(cx, obj, description,
+                                       gjs_context_get_const_string(cx, property_name),
+                                       value);
+}
+
+template<typename T>
+bool gjs_object_require_converted_property(JSContext       *cx,
+                                           JS::HandleObject obj,
+                                           const char      *description,
+                                           GjsConstString   property_name,
+                                           T                value)
+{
+    return gjs_object_require_converted_property(cx, obj, description,
+                                                 gjs_context_get_const_string(cx, property_name),
+                                                 value);
+}
 
 #endif  /* __GJS_JSAPI_UTIL_H__ */
