@@ -59,26 +59,26 @@ gjs_context_get_frame_info(JSContext                              *context,
     JSAutoCompartment ac(context, global);
 
     JS::RootedId error_id(context, gjs_intern_string_to_id(context, "Error"));
-    if (!gjs_object_require_property_value(context, global, "global object",
-                                           error_id, &constructor))
+    if (!gjs_object_require_property(context, global, "global object",
+                                     error_id, &constructor))
         return false;
 
     JS::RootedObject err_obj(context, JS_New(context, constructor,
                                              JS::HandleValueArray::empty()));
 
-    if (!stack.empty() &&
-        !gjs_object_get_property_const(context, err_obj, GJS_STRING_STACK,
-                                       stack.ref()))
+    if (stack &&
+        !gjs_object_get_property(context, err_obj, GJS_STRING_STACK,
+                                 stack.ref()))
         return false;
 
-    if (!fileName.empty() &&
-        !gjs_object_get_property_const(context, err_obj, GJS_STRING_FILENAME,
-                                       fileName.ref()))
+    if (fileName &&
+        !gjs_object_get_property(context, err_obj, GJS_STRING_FILENAME,
+                                 fileName.ref()))
         return false;
 
-    if (!lineNumber.empty() &&
-        !gjs_object_get_property_const(context, err_obj, GJS_STRING_LINE_NUMBER,
-                                       lineNumber.ref()))
+    if (lineNumber &&
+        !gjs_object_get_property(context, err_obj, GJS_STRING_LINE_NUMBER,
+                                 lineNumber.ref()))
         return false;
 
     return true;
@@ -95,9 +95,9 @@ gjs_context_print_stack_stderr(GjsContext *context)
 
     /* Stderr is locale encoding, so we use string_to_filename here */
     /* COMPAT: mozilla::Maybe gains a much more usable API in future versions */
-    mozilla::Maybe<JS::MutableHandleValue> m_stack, m_file, m_line;
-    m_stack.construct(&v_stack);
-    if (!gjs_context_get_frame_info(cx, m_stack, m_file, m_line) ||
+    mozilla::Maybe<JS::MutableHandleValue> none,
+        m_stack = mozilla::Some<JS::MutableHandleValue>(&v_stack);
+    if (!gjs_context_get_frame_info(cx, m_stack, none, none) ||
         !gjs_string_to_filename(cx, v_stack, &stack)) {
         g_printerr("No stack trace available\n");
         return;
