@@ -25,7 +25,6 @@
 #include <config.h>
 
 #include <sys/types.h>
-#include <unistd.h>
 #include <time.h>
 
 #include <gjs/context.h>
@@ -35,6 +34,9 @@
 #include "gjs/jsapi-util-args.h"
 #include "system.h"
 
+/* Note that this cannot be relied on to test whether two objects are the same!
+ * SpiderMonkey can move objects around in memory during garbage collection,
+ * and it can also deduplicate identical instances of objects in memory. */
 static bool
 gjs_address_of(JSContext *context,
                unsigned   argc,
@@ -160,7 +162,7 @@ gjs_js_define_system_stuff(JSContext              *context,
     char *program_name;
     bool retval;
 
-    module.set(JS_NewObject(context, NULL, JS::NullPtr(), JS::NullPtr()));
+    module.set(JS_NewObject(context, NULL));
 
     if (!JS_DefineFunctions(context, module, &module_funcs[0]))
         return false;
@@ -183,15 +185,13 @@ gjs_js_define_system_stuff(JSContext              *context,
                            "programInvocationName",
                            value,
                            GJS_MODULE_PROP_FLAGS | JSPROP_READONLY,
-                           JS_PropertyStub,
-                           JS_StrictPropertyStub))
+                           JS_STUBGETTER, JS_STUBSETTER))
         goto out;
 
     if (!JS_DefineProperty(context, module,
                            "version", GJS_VERSION,
                            GJS_MODULE_PROP_FLAGS | JSPROP_READONLY,
-                           JS_PropertyStub,
-                           JS_StrictPropertyStub))
+                           JS_STUBGETTER, JS_STUBSETTER))
         goto out;
 
     retval = true;
