@@ -58,7 +58,7 @@ gjs_unit_test_fixture_setup(GjsUnitTestFixture *fx,
 
     /* This is for shoving private data into the error reporter callback */
     g_object_set_data(G_OBJECT(fx->gjs_context), "test fixture", fx);
-    JS_SetErrorReporter(fx->cx, test_error_reporter);
+    JS_SetErrorReporter(JS_GetRuntime(fx->cx), test_error_reporter);
 
     JS_BeginRequest(fx->cx);
 
@@ -67,19 +67,30 @@ gjs_unit_test_fixture_setup(GjsUnitTestFixture *fx,
 }
 
 void
-gjs_unit_test_fixture_teardown(GjsUnitTestFixture *fx,
-                               gconstpointer      unused)
+gjs_unit_test_destroy_context(GjsUnitTestFixture *fx)
 {
     JS_LeaveCompartment(fx->cx, fx->compartment);
     JS_EndRequest(fx->cx);
 
     g_object_unref(fx->gjs_context);
+}
 
+void
+gjs_unit_test_teardown_context_already_destroyed(GjsUnitTestFixture *fx)
+{
     if (fx->message != NULL)
         g_printerr("**\n%s\n", fx->message);
     g_free(fx->message);
 }
 
+void
+gjs_unit_test_fixture_teardown(GjsUnitTestFixture *fx,
+                               gconstpointer      unused)
+{
+    gjs_unit_test_destroy_context(fx);
+    gjs_unit_test_teardown_context_already_destroyed(fx);
+}
+
 /* Fork a process that waits the given time then
  * sends us ABRT
  */
